
Codecs
======

.. automodule:: av.codec.codec

    .. autoclass:: Codec
        :members:

.. automodule:: av.codec.context

    .. autoclass:: ThreadType
        :members:

    .. autoclass:: SkipType
        :members:

    .. autoclass:: CodecContext
        :members:
